import {Component, OnInit} from '@angular/core';
import {FormsModule} from '@angular/forms';
import {MatButtonModule} from '@angular/material/button';
import {MatFormField, MatLabel} from '@angular/material/form-field';
import {MatInput} from '@angular/material/input';
import {MatTableModule} from '@angular/material/table';
import UserData from '@core/auth/UserData';
import {AdministratablePlayer, AdminService, PlayerFilter} from '@core/server';
import {AsyncPipe} from '@angular/common';
import {AuthService} from '@core/auth/auth.service';
import {MatIcon} from '@angular/material/icon';

@Component({
    selector: 'app-admin-overview',
    templateUrl: './admin-overview.component.html',
    styleUrls: ['./admin-overview.component.scss'],
    standalone: true,
    imports: [MatTableModule, MatButtonModule, MatLabel, MatInput, FormsModule, MatFormField, AsyncPipe, MatIcon]
})
export class AdminOverviewComponent implements OnInit {
    displayedColumns: Array<string> = ['username', 'ban'];
    userList: Array<AdministratablePlayer> = [];
    searchQuery: string = '';

    constructor(private adminService: AdminService, protected authService: AuthService) {
    }

    ngOnInit(): void {
        this.authService.$user.subscribe((user) => {
            if (user != undefined) {
                return this.fetchPlayers();
            }
        });
    }

    fetchPlayers(): void {
        const filter: PlayerFilter = {
            page: 0,
            pageSize: 32,
            order: PlayerFilter.OrderEnum.Ascending,
            username: this.searchQuery,
            sortBy: 'username'
        };

        this.adminService.getAllPlayers(filter).subscribe(
            (players) => {
                this.userList = players;
            },
            (error) => {
                console.error('Error fetching players:', error);
            }
        );
    }

    banPlayer(user: UserData): void {
        console.log(`Banning user: ${user.username}`);
        //implement banning logic
    }

    onSearch(): void {
        this.fetchPlayers();
    }

    resetFilter(): void {
        this.searchQuery = '';
        this.fetchPlayers();
    }
}
